@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -162,7 +162,7 @@ public class WebserviceCollector implements ServiceListener {
         {
             final Object name = ref.getProperty(WEBSERVICE_NAME);
             final String sName = null == name ? null : name.toString();
-            if (!isEmpty(sName)) {
+            if (!com.openexchange.java.Strings.isEmpty(sName)) {
                 return sName;
             }
         }
@@ -170,11 +170,11 @@ public class WebserviceCollector implements ServiceListener {
         {
             final WebService webService = service.getClass().getAnnotation(WebService.class);
             String serviceName = webService.serviceName();
-            if (!isEmpty(serviceName)) {
+            if (!com.openexchange.java.Strings.isEmpty(serviceName)) {
                 return serviceName;
             }
             serviceName = webService.name();
-            if (!isEmpty(serviceName)) {
+            if (!com.openexchange.java.Strings.isEmpty(serviceName)) {
                 return serviceName;
             }
         }
@@ -182,18 +182,6 @@ public class WebserviceCollector implements ServiceListener {
         return service.getClass().getSimpleName();
     }
 
-    private static boolean isEmpty(final String string) {
-        if (null == string) {
-            return true;
-        }
-        final int len = string.length();
-        boolean isWhitespace = true;
-        for (int i = 0; isWhitespace && i < len; i++) {
-            isWhitespace = com.openexchange.java.Strings.isWhitespace(string.charAt(i));
-        }
-        return isWhitespace;
-    }
-
     private void remove(final String name, final Object service) {
         final Endpoint endpoint = endpoints.remove(name);
         if (endpoint != null) {
